@@ -6,13 +6,13 @@ import numpy as np
 from one.api import ONE
 import one.alf.io as alfio
 
-from ibllib.ephys.neuropixel import SITES_COORDINATES
+from neuropixel import TIP_SIZE_UM, trace_header
 import ibllib.atlas as atlas
 from ibllib.ephys.spikes import probes_description as extract_probes
-from ibllib.dsp.utils import fcn_cosine
-from ibllib.ephys.neuropixel import TIP_SIZE_UM, trace_header
 from ibllib.qc import base
 
+from neurodsp.utils import fcn_cosine
+
 
 _logger = logging.getLogger('ibllib')
 
@@ -93,7 +93,8 @@ def get_micro_manipulator_data(subject, one=None, force_extract=False):
             else:
                 _logger.warning(f"no channel.localCoordinates found for {ses['local_path']}."
                                 f"Assumes checkerboard pattern")
-                probe['sites_coordinates'].append(SITES_COORDINATES)
+                th = trace_header(version=1)
+                probe['sites_coordinates'].append(np.c_[th['x'], th['y']])
         # put the session information in there
         probe['session'] = [ses] * len(probe.description)
         probes = probes.append(probe)
